// Copyright (C) 2019  Wilko Manger
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

library future_or_builder;

import 'dart:async';

import 'package:flutter/widgets.dart';

/// Builds immediately if the `FutureOr` is the `T`,
/// other wise build a `FutureBuilder`.
class FutureOrBuilder<T> extends StatelessWidget {
  final FutureOr<T> futureOr;
  final AsyncWidgetBuilder<T> builder;

  const FutureOrBuilder({
    Key key,
    @required this.futureOr,
    @required this.builder,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    if (futureOr is T) {
      return builder(
        context,
        AsyncSnapshot.withData(
          ConnectionState.done,
          futureOr,
        ),
      );
    } else {
      return FutureBuilder<T>(
        future: futureOr,
        builder: builder,
      );
    }
  }
}
